import { Component, OnInit } from '@angular/core'; 
import { ListService, PagedResultDto } from '@abp/ng.core';
import { BookIssueDto, BookIssueListDto, BookIssueService } from '@proxy/book-issued';
import { FormBuilder, FormControl, FormGroup, Validators } from '@angular/forms';
import { BookDto, BookService } from '@proxy/books';
import { CustomerDto, CustomerService } from '@proxy/customers';
import { ConfirmationService,Confirmation } from '@abp/ng.theme.shared';

@Component({
  selector: 'app-book-issue',
  templateUrl: './book-issue.component.html',
  styleUrl: './book-issue.component.scss',
  providers: [ListService]
})
export class BookIssueComponent implements OnInit {
  isModalOpen = false;

  form:FormGroup;
  dropDownbook= {} as Array<BookDto>;
  dropDownCustomer= {} as Array<CustomerDto>;
  bookIssueList = { items: [], totalCount: 0 } as PagedResultDto<BookIssueListDto>; 

  constructor(public readonly list: ListService,
    private bookIssuedService: BookIssueService,
    private bookService: BookService,
    private customerService: CustomerService,
    private fb: FormBuilder,
    private confirmation: ConfirmationService ) {}
 
    ngOnInit(): void {
     this.dropdowninitiale();
     
    const bookStreamCreator = (query) => this.bookIssuedService.getList(query);

    this.list.hookToQuery(bookStreamCreator).subscribe((response) => {
      this.bookIssueList = response;
    });
    }

    createBookIssue() {
      this.buildForm();
      this.isModalOpen = true;
    }

    buildForm() {
   
      this.form = this.fb.group({
        bookId: ['', Validators.required],
        customerId: ['', Validators.required],
      }); 
    }

    save() {
      if (this.form.invalid) {
        return;
      } 
      this.bookIssuedService.create(this.form.value).subscribe(() => {
        this.isModalOpen = false;
        this.form.reset();
        this.list.get();
      });
    
 }

 dropdowninitiale(){
  this.bookService.getBookDropDown().subscribe((response)=>{
    this.dropDownbook = response;

  });
  this.customerService.getcustomerDropDown().subscribe((response)=>{
    this.dropDownCustomer = response;

  });
 }
 delete(bookIssueId: string) {
  this.confirmation.warn('::AreYouSureToUnIssue', '::AreYouSure').subscribe((status) => {
    if (status === Confirmation.Status.confirm) {
      this.bookIssuedService.delete(bookIssueId).subscribe(() => this.list.get());
    }
  });
}
  
}
