import type { BookIssueDto, BookIssueListDto } from './models';
import { RestService, Rest } from '@abp/ng.core';
import type { PagedResultDto } from '@abp/ng.core';
import { Injectable } from '@angular/core';

@Injectable({
  providedIn: 'root',
})
export class BookIssueService {
  apiName = 'Default';
  

  create = (input: BookIssueDto, config?: Partial<Rest.Config>) =>
    this.restService.request<any, BookIssueDto>({
      method: 'POST',
      url: '/api/app/book-issue',
      body: input,
    },
    { apiName: this.apiName,...config });
  

  delete = (id: string, config?: Partial<Rest.Config>) =>
    this.restService.request<any, void>({
      method: 'DELETE',
      url: `/api/app/book-issue/${id}`,
    },
    { apiName: this.apiName,...config });
  

  get = (id: string, config?: Partial<Rest.Config>) =>
    this.restService.request<any, BookIssueDto>({
      method: 'GET',
      url: `/api/app/book-issue/${id}`,
    },
    { apiName: this.apiName,...config });
  

  getList = (config?: Partial<Rest.Config>) =>
    this.restService.request<any, PagedResultDto<BookIssueListDto>>({
      method: 'GET',
      url: '/api/app/book-issue',
    },
    { apiName: this.apiName,...config });
  

  update = (id: string, input: BookIssueDto, config?: Partial<Rest.Config>) =>
    this.restService.request<any, void>({
      method: 'PUT',
      url: `/api/app/book-issue/${id}`,
      body: input,
    },
    { apiName: this.apiName,...config });

  constructor(private restService: RestService) {}
}
