﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Acme.BookStore.BookIssued;
using Volo.Abp.Application.Dtos;
using Acme.BookStore.Permissions;
using Microsoft.AspNetCore.Authorization;


namespace Acme.BookStore.BookIssued
{
    public class BookIssueAppService : BookStoreAppService, IBookIssueAppService
    {
        private readonly IBookIssueRepository _bookIssueRepository;
        private readonly BookIssueManager _bookIssueManager;

        public BookIssueAppService(
            IBookIssueRepository bookIssueRepository,
            BookIssueManager bookIssueManager)
        {
            _bookIssueRepository = bookIssueRepository;
            _bookIssueManager = bookIssueManager;
        }

        public async Task<BookIssueDto> GetAsync(Guid id)
        {
            var cus = await _bookIssueRepository.GetAsync(id);
            return ObjectMapper.Map<BookIssue, BookIssueDto>(cus);
        }

        public async Task<PagedResultDto<BookIssueListDto>> GetListAsync()
        {

            var cus = await _bookIssueRepository.BookIssueList();

            return new PagedResultDto<BookIssueListDto>(
                cus.Count(),
                ObjectMapper.Map<List<BookIssueList>, List<BookIssueListDto>>(cus)
            );
        }
         

         [Authorize(BookStorePermissions.BookIssued.Create)]

        public async Task<BookIssueDto> CreateAsync(BookIssueDto input)
        {
            var cus = ObjectMapper.Map<BookIssueDto, BookIssue>(input);
            var cust = await _bookIssueManager.CreateAsync(cus);

            var res =  await _bookIssueRepository.InsertAsync(cust);

            return ObjectMapper.Map<BookIssue, BookIssueDto>(cust);
        }

        [Authorize(BookStorePermissions.BookIssued.Edit)]
        public async Task UpdateAsync(Guid id, BookIssueDto input)
        {
            var cus = await _bookIssueRepository.GetAsync(id);
             
            await _bookIssueRepository.UpdateAsync(cus);
        }


        [Authorize(BookStorePermissions.BookIssued.Delete)]
        public async Task DeleteAsync(Guid id)
        {
            await _bookIssueRepository.DeleteAsync(id);
        }

    }
}
