﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Volo.Abp.Application.Dtos;
using Volo.Abp.Application.Services;
using Volo.Abp.Domain.Repositories;
using Acme.BookStore.Permissions; 

namespace Acme.BookStore.Books
{

    public class BookAppService :
        CrudAppService<
            Book, //The Book entity
            BookDto, //Used to show books
            Guid, //Primary key of the book entity
            PagedAndSortedResultRequestDto, //Used for paging/sorting
            CreateUpdateBookDto>, //Used to create/update a book
        IBookAppService //implement the IBookAppService
    {
         private readonly IRepository<Book, Guid> _bookRepository;
        public BookAppService(IRepository<Book, Guid> repository)
            : base(repository)
        {
           _bookRepository = repository;
            GetPolicyName = BookStorePermissions.Books.Default;
            GetListPolicyName = BookStorePermissions.Books.Default;
            CreatePolicyName = BookStorePermissions.Books.Create;
            UpdatePolicyName = BookStorePermissions.Books.Edit;
            DeletePolicyName = BookStorePermissions.Books.Delete;
        }

        public async Task<List<BookDto>> GetBookDropDown()
        {
            var cus = await _bookRepository.GetListAsync();
            cus = cus == null ? new List<Book>() : cus;
            return ObjectMapper.Map<List<Book>, List<BookDto>>(cus);
        }

    }
}
