﻿using Acme.BookStore.Customers;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Volo.Abp.Application.Dtos;
using Volo.Abp.Application.Services;
using Volo.Abp.ObjectMapping;
using Acme.BookStore.Permissions;
using Microsoft.AspNetCore.Authorization;

namespace Acme.BookStore.Customers
{
    public class CustomerAppService: BookStoreAppService, ICustomerAppService
    {
        private readonly ICustomerRepository _customerRepository;
        private readonly CustomerManager _customerManager;

        public CustomerAppService(
            ICustomerRepository customerRepository,
            CustomerManager customerManager)
        {
            _customerRepository = customerRepository;
            _customerManager = customerManager;
        }

        public async Task<CustomerDto> GetAsync(Guid id)
        {
            var cus = await _customerRepository.GetAsync(id);
            return ObjectMapper.Map<Customer, CustomerDto>(cus);
        }
        public async Task<List<CustomerDto>> GetcustomerDropDown()
        {
            var cus = await _customerRepository.GetListAsync();
            cus = cus == null ? new List<Customer>() : cus;
            return ObjectMapper.Map<List<Customer>, List<CustomerDto>>(cus);
        }
         
        public async Task<PagedResultDto<CustomerDto>> GetListAsync()
        { 

            var cus = await _customerRepository.GetListAsync();
             
            return new PagedResultDto<CustomerDto>(
                cus.Count(),
                ObjectMapper.Map<List<Customer>, List<CustomerDto>>(cus)
            );
        }


        [Authorize(BookStorePermissions.Customers.Create)]

        public async Task<CustomerDto> CreateAsync(CustomerDto input)
        {
           var cus = ObjectMapper.Map<CustomerDto,Customer>(input);
            var cust = await _customerManager.CreateAsync(cus); 

            await _customerRepository.InsertAsync(cust);

            return ObjectMapper.Map<Customer, CustomerDto>(cust);
        }
         
        [Authorize(BookStorePermissions.Customers.Edit)]

        public async Task UpdateAsync(Guid id, CustomerDto input)
        {
            var cus = await _customerRepository.GetAsync(id);

            if (cus.Phone == input.Phone)
            {
                await _customerManager.ChangeNameAsync(cus, input.FirstName,input.LastName);
            }
             
            await _customerRepository.UpdateAsync(cus);
        }

         
        [Authorize(BookStorePermissions.Customers.Delete)]

        public async Task DeleteAsync(Guid id)
        {
            await _customerRepository.DeleteAsync(id);
        }
    }
}
