﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks; 
using Acme.BookStore.Books;
using Volo.Abp.Data;
using Volo.Abp.DependencyInjection;
using Volo.Abp.Domain.Repositories;

using Acme.BookStore.Authors;
using Acme.BookStore.Customers;

namespace Acme.BookStore
{
    public class BookStoreDataSeederContributor
    : IDataSeedContributor, ITransientDependency
    {
        private readonly IRepository<Book, Guid> _bookRepository;
        private readonly IAuthorRepository _authorRepository;
        private readonly ICustomerRepository _customerRepository;
        private readonly AuthorManager _authorManager;
        private readonly CustomerManager _customerManager;

        public BookStoreDataSeederContributor(IRepository<Book, Guid> bookRepository,
            IAuthorRepository authorRepository, 
            AuthorManager authorManager,
            ICustomerRepository customerRepository,
            CustomerManager customerManager
            )
        {
            _bookRepository = bookRepository;

            _authorRepository = authorRepository;
            _authorManager = authorManager;

            _customerRepository = customerRepository;
            _customerManager = customerManager;
        }

        public async Task SeedAsync(DataSeedContext context)
        {
            if (await _bookRepository.GetCountAsync() <= 0)
            {
                await _bookRepository.InsertAsync(
                    new Book
                    {
                        Name = "1984",
                        Type = BookType.Dystopia,
                        PublishDate = new DateTime(1949, 6, 8),
                        Price = 19.84f
                    },
                    autoSave: true
                );

                await _bookRepository.InsertAsync(
                    new Book
                    {
                        Name = "The Hitchhiker's Guide to the Galaxy",
                        Type = BookType.ScienceFiction,
                        PublishDate = new DateTime(1995, 9, 27),
                        Price = 42.0f
                    },
                    autoSave: true
                );
            }


            if (await _authorRepository.GetCountAsync() <= 0)
            {
                await _authorRepository.InsertAsync(
                await _authorManager.CreateAsync(
                        "George Orwell",
                        new DateTime(1903, 06, 25),
                        "Orwell produced literary criticism and poetry, fiction and polemical journalism; and is best known for the allegorical novella Animal Farm (1945) and the dystopian novel Nineteen Eighty-Four (1949)."
                    )
                );
                await _authorRepository.InsertAsync(
                await _authorManager.CreateAsync(
                        "Douglas Adams",
                        new DateTime(1952, 03, 11),
                        "Douglas Adams was an English author, screenwriter, essayist, humorist, satirist and dramatist. Adams was an advocate for environmentalism and conservation, a lover of fast cars, technological innovation and the Apple Macintosh, and a self-proclaimed 'radical atheist'."
                    )
                );
            }

            if (await _customerRepository.GetCountAsync() <= 0)
            {
                Customer customer = new Customer(new Guid(), "soumen", "pal", "9091184026", "haripal");

                await _customerRepository.InsertAsync(
                await _customerManager.CreateAsync(customer)
                );
            }

        }


    }
}
