﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Volo.Abp;
using Volo.Abp.Domain.Entities.Auditing;

namespace Acme.BookStore.Customers
{
    public class Customer : FullAuditedAggregateRoot<Guid>
    {
        public string FirstName { get; set; }
        public string LastName { get; set; } 
        public string Phone { get; set; }
        public string Address { get; set; }
        private Customer()
        {
            /* This constructor is for deserialization / ORM purpose */
        }
        internal Customer(Guid id, string firstName, string lastName, string phone, string address) : base(id)
        {
            this.FirstName = firstName;
            this.LastName = lastName;
            this.Phone = phone;
            this.Address = address;
        }

        internal Customer ChangeFirstName(string firstname)
        {
            SetFirstName(firstname);
            return this;
        }

        private void SetFirstName(string firstName)
        {
            firstName = Check.NotNullOrWhiteSpace(
                firstName,
                nameof(firstName),
                maxLength: CustomerConsts.MaxNameLength
            );
            this.FirstName = firstName;
        }
        internal Customer ChangeLastName(string lastname)
        {
            SetLastName(lastname);
            return this;
        }

        private void SetLastName(string lastname)
        {
            lastname = Check.NotNullOrWhiteSpace(
                lastname,
                nameof(lastname),
                maxLength: CustomerConsts.MaxNameLength
            );
            this.LastName = lastname;
        }
    }
}
