﻿using Acme.BookStore.Authors;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Volo.Abp.Guids;
using Volo.Abp;
using Volo.Abp.Domain.Services;

namespace Acme.BookStore.Customers
{
    
    public class CustomerManager : DomainService
    {
        private readonly ICustomerRepository _customerRepository;
        public CustomerManager(ICustomerRepository customerRepository) 
        {
            _customerRepository = customerRepository;
        }

        public async Task<Customer> CreateAsync(
           Customer customer)
        {
            Check.NotNullOrWhiteSpace(customer.FirstName, nameof(customer.FirstName));
            Check.NotNullOrWhiteSpace(customer.LastName, nameof(customer.LastName));

            var existingAuthor = await _customerRepository.FindByPhoneAsync(customer.Phone);
            if (existingAuthor != null)
            {
                throw new CustomerErrorException(customer.Phone);
            }
            return new Customer(
                GuidGenerator.Create(),
                customer.FirstName,
                    customer.LastName,
                customer.Phone,
                customer.Address
            );
        }

        public async Task ChangeNameAsync(
         Customer customer,
          string firstName,string lastName)
        {
            Check.NotNull(customer, nameof(customer));
            Check.NotNullOrWhiteSpace(customer.FirstName, nameof(customer.FirstName));
            Check.NotNullOrWhiteSpace(customer.LastName, nameof(customer.LastName));

            customer.ChangeFirstName(firstName);
            customer.ChangeLastName(lastName);
        }

    }
}
